@@ -49,6 +49,7 @@ def search_templates(old_admin_name, new_admin_name, server_role):
         '/etc/freeradius/3.0/mods-available/ldap',
         '/etc/bind/named.conf.samba4', '/var/www/univention/meta.json',
         '/etc/issue', '/etc/welcome.msg', '/etc/samba/base.conf', '/etc/cups/cups-files.conf',
+        '/var/lib/univention-appcenter/apps/keycloak/conf/UCS/login/messages/messages_de.properties',
     ]
     if server_role != 'domaincontroller_master':
         should_contain_admin.remove('/etc/ldap/slapd.conf')
@@ -144,7 +145,7 @@ def test_rename_domain_users():
             print('\n##################################################################')
             print('Cleanup')
             print('##################################################################\n')
-            subprocess.call(['udm-test', 'users/user', 'modify', '--dn=%s' % (new_admin_dn), '--set', 'username=%s' % (old_admin_name), '--binddn=%s' % (new_admin_dn), '--bindpwd=univention'] + credentials)
+            subprocess.call(['udm-test', 'users/user', 'modify', '--dn=%s' % new_admin_dn, '--set', 'username=%s' % old_admin_name, '--binddn=%s' % new_admin_dn, '--bindpwd=univention', *credentials])
 
             # wait until renaming and UCR Variable is set back again
             utils.wait_for_replication_and_postrun()
